"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function run(f, code) {
    for (;;) {
        const res = f(code);
        if (res === code) {
            return code;
        }
        code = res;
    }
}
function img(code) {
    return code
        .replace(/\[img]/g, `<img src="`)
        .replace(/\[img=.*?]/g, `<img src="`)
        .replace(/\[\/img]/g, `">`);
}
function i(code) {
    return code
        .replace(/\[i]/g, `<i>`)
        .replace(/\[i\=s]/g, `<i>`)
        .replace(/\[\/i]/g, `</i>`);
}
function b(code) {
    return code
        .replace(/\[b]/g, `<b>`)
        .replace(/\[b\=s]/g, `<b>`)
        .replace(/\[\/b]/g, `</b>`);
}
function attr(o) {
    return function (code) {
        let start = code.indexOf(o.start);
        if (start === -1) {
            return code;
        }
        let end = code.indexOf(']', start);
        if (end === -1) {
            return code;
        }
        const attr = code.substring(start + o.start.length, end);
        const prefix = code.substring(0, start);
        start = end + 1;
        if (start >= code.length) {
            return code;
        }
        end = code.indexOf(o.end, start);
        if (end === -1) {
            return code;
        }
        const body = code.substring(start, end);
        const suffix = code.substring(end + o.end.length);
        const span = o.f(attr, body);
        return prefix + span + suffix;
    };
}
const size = attr({
    start: '[size=',
    end: '[/size]',
    f: (attr, body) => `<span style="font-size: ${attr}">${body}</span>`,
});
const font = attr({
    start: '[font=',
    end: '[/font]',
    f: (attr, body) => {
        attr = attr.replace(', &quot;', '');
        return `<span style="font-family: ${attr}">${body}</span>`;
    },
});
const color = attr({
    start: '[color=',
    end: '[/color]',
    f: (attr, body) => {
        if (attr.length === 5 && attr[0] === '#' && attr[4] === '0') {
            attr = attr.substring(0, 4); // make transparent text visible
        }
        return `<span style="color: ${attr}">${body}</span>`;
    },
});
const url = attr({
    start: '[url=',
    end: '[/url]',
    f: (attr, body) => `<a href="${attr}">${body}</a>`,
});
let attachments = [];
let attachmentMode;
const attach = attr({
    start: '[attach',
    end: '[/attach]',
    f: (_attr, body) => {
        const src = attachments.shift();
        switch (attachmentMode) {
            case 'img':
                return `<img src="${src}">`;
                break;
            case 'ion-img':
                return `<ion-img src="${src}"></ion-img>`;
            case 'a':
                return `<a src="${src}">${src}</a>`;
            default:
                return `[attach]${body}[/attach]`; // original format
        }
    },
});
function bbcode_to_html(code, options) {
    const r = (f) => {
        code = run(f, code);
    };
    r(img);
    r(size);
    r(font);
    r(color);
    r(i);
    r(b);
    r(url);
    if (options === null || options === void 0 ? void 0 : options.attachment) {
        attachments = options.attachment.links;
        attachmentMode = options.attachment.mode;
        r(attach);
    }
    return code;
}
exports.bbcode_to_html = bbcode_to_html;
function extract_images_from_bbcode(code, imgs = []) {
    const ss = code.split('[img]');
    if (ss.length === 1) {
        return imgs;
    }
    ss.forEach(s => {
        const ss = s.split('[/img]');
        if (ss.length === 1) {
            return;
        }
        let img = ss[0];
        if (img.includes('[img=')) {
            img = img.split('[img=')[1];
            img = img.substring(img.indexOf(']') + 1);
        }
        imgs.push(img);
    });
    return imgs;
}
exports.extract_images_from_bbcode = extract_images_from_bbcode;
//# sourceMappingURL=bbcode.js.map